# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/recipe/v1/recipe.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/recipe/v1/recipe.proto',
  package='github.com.metaprov.modelaapi.services.recipe.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/metaprov/modelaapi/services/recipe/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=github.com/metaprov/modelaapi/services/recipe/v1/recipe.proto\x12\x30github.com.metaprov.modelaapi.services.recipe.v1\x1a\x1cgoogle/api/annotations.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xb8\x01\n\x12ListRecipesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"f\n\x13ListRecipesResponse\x12O\n\x05items\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeList\"a\n\x13\x43reateRecipeRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x16\n\x14\x43reateRecipeResponse\"a\n\x13UpdateRecipeRequest\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\"\x16\n\x14UpdateRecipeResponse\"3\n\x10GetRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x87\x01\n\x14ProfileRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x04spec\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeSpec\"c\n\x15ProfileRecipeResponse\x12J\n\x05table\x18\x01 \x01(\x0b\x32;.github.com.metaprov.modelaapi.services.common.v1.TableView\"\x83\x01\n\x10RunRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12N\n\x04spec\x18\x03 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.RecipeSpec\"o\n\x11RunRecipeResponse\x12L\n\x06recipe\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"m\n\x11GetRecipeResponse\x12J\n\x04item\x18\x01 \x01(\x0b\x32<.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Recipe\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"6\n\x13\x44\x65leteRecipeRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteRecipeResponse2\x9b\n\n\rRecipeService\x12\xaf\x01\n\x0bListRecipes\x12\x44.github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest\x1a\x45.github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesResponse\"\x13\x82\xd3\xe4\x93\x02\r\x12\x0b/v1/recipes\x12\xb5\x01\n\x0c\x43reateRecipe\x12\x45.github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeRequest\x1a\x46.github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/recipes:\x01*\x12\xb0\x01\n\tGetRecipe\x12\x42.github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeRequest\x1a\x43.github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/recipes/{name}\x12\xb4\x01\n\tRunRecipe\x12\x42.github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeRequest\x1a\x43.github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/recipes/{name}:run\x12\xc4\x01\n\rProfileRecipe\x12\x46.github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeRequest\x1aG.github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/recipes/{name}:profile\x12\xcc\x01\n\x0cUpdateRecipe\x12\x45.github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeRequest\x1a\x46.github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeResponse\"-\x82\xd3\xe4\x93\x02\'\x1a\"/v1/recipes/{recipe.metadata.name}:\x01*\x12\x9f\x01\n\x0c\x44\x65leteRecipe\x12\x45.github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeRequest\x1a\x46.github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeResponse\"\x00\x42\x32Z0github.com/metaprov/modelaapi/services/recipe/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTRECIPESREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=418,
  serialized_end=463,
)

_LISTRECIPESREQUEST = _descriptor.Descriptor(
  name='ListRecipesRequest',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest.labels', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTRECIPESREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=279,
  serialized_end=463,
)


_LISTRECIPESRESPONSE = _descriptor.Descriptor(
  name='ListRecipesResponse',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=465,
  serialized_end=567,
)


_CREATERECIPEREQUEST = _descriptor.Descriptor(
  name='CreateRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=666,
)


_CREATERECIPERESPONSE = _descriptor.Descriptor(
  name='CreateRecipeResponse',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=668,
  serialized_end=690,
)


_UPDATERECIPEREQUEST = _descriptor.Descriptor(
  name='UpdateRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=692,
  serialized_end=789,
)


_UPDATERECIPERESPONSE = _descriptor.Descriptor(
  name='UpdateRecipeResponse',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=791,
  serialized_end=813,
)


_GETRECIPEREQUEST = _descriptor.Descriptor(
  name='GetRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=866,
)


_PROFILERECIPEREQUEST = _descriptor.Descriptor(
  name='ProfileRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeRequest.spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=869,
  serialized_end=1004,
)


_PROFILERECIPERESPONSE = _descriptor.Descriptor(
  name='ProfileRecipeResponse',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeResponse.table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1006,
  serialized_end=1105,
)


_RUNRECIPEREQUEST = _descriptor.Descriptor(
  name='RunRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spec', full_name='github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeRequest.spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1108,
  serialized_end=1239,
)


_RUNRECIPERESPONSE = _descriptor.Descriptor(
  name='RunRecipeResponse',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='recipe', full_name='github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeResponse.recipe', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1352,
)


_GETRECIPERESPONSE = _descriptor.Descriptor(
  name='GetRecipeResponse',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1463,
)


_DELETERECIPEREQUEST = _descriptor.Descriptor(
  name='DeleteRecipeRequest',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1465,
  serialized_end=1519,
)


_DELETERECIPERESPONSE = _descriptor.Descriptor(
  name='DeleteRecipeResponse',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1521,
  serialized_end=1543,
)

_LISTRECIPESREQUEST_LABELSENTRY.containing_type = _LISTRECIPESREQUEST
_LISTRECIPESREQUEST.fields_by_name['labels'].message_type = _LISTRECIPESREQUEST_LABELSENTRY
_LISTRECIPESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPELIST
_CREATERECIPEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
_UPDATERECIPEREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
_PROFILERECIPEREQUEST.fields_by_name['spec'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPESPEC
_PROFILERECIPERESPONSE.fields_by_name['table'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2._TABLEVIEW
_RUNRECIPEREQUEST.fields_by_name['spec'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPESPEC
_RUNRECIPERESPONSE.fields_by_name['recipe'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
_GETRECIPERESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._RECIPE
DESCRIPTOR.message_types_by_name['ListRecipesRequest'] = _LISTRECIPESREQUEST
DESCRIPTOR.message_types_by_name['ListRecipesResponse'] = _LISTRECIPESRESPONSE
DESCRIPTOR.message_types_by_name['CreateRecipeRequest'] = _CREATERECIPEREQUEST
DESCRIPTOR.message_types_by_name['CreateRecipeResponse'] = _CREATERECIPERESPONSE
DESCRIPTOR.message_types_by_name['UpdateRecipeRequest'] = _UPDATERECIPEREQUEST
DESCRIPTOR.message_types_by_name['UpdateRecipeResponse'] = _UPDATERECIPERESPONSE
DESCRIPTOR.message_types_by_name['GetRecipeRequest'] = _GETRECIPEREQUEST
DESCRIPTOR.message_types_by_name['ProfileRecipeRequest'] = _PROFILERECIPEREQUEST
DESCRIPTOR.message_types_by_name['ProfileRecipeResponse'] = _PROFILERECIPERESPONSE
DESCRIPTOR.message_types_by_name['RunRecipeRequest'] = _RUNRECIPEREQUEST
DESCRIPTOR.message_types_by_name['RunRecipeResponse'] = _RUNRECIPERESPONSE
DESCRIPTOR.message_types_by_name['GetRecipeResponse'] = _GETRECIPERESPONSE
DESCRIPTOR.message_types_by_name['DeleteRecipeRequest'] = _DELETERECIPEREQUEST
DESCRIPTOR.message_types_by_name['DeleteRecipeResponse'] = _DELETERECIPERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListRecipesRequest = _reflection.GeneratedProtocolMessageType('ListRecipesRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTRECIPESREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTRECIPESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesRequest)
  })
_sym_db.RegisterMessage(ListRecipesRequest)
_sym_db.RegisterMessage(ListRecipesRequest.LabelsEntry)

ListRecipesResponse = _reflection.GeneratedProtocolMessageType('ListRecipesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTRECIPESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ListRecipesResponse)
  })
_sym_db.RegisterMessage(ListRecipesResponse)

CreateRecipeRequest = _reflection.GeneratedProtocolMessageType('CreateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeRequest)
  })
_sym_db.RegisterMessage(CreateRecipeRequest)

CreateRecipeResponse = _reflection.GeneratedProtocolMessageType('CreateRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATERECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.CreateRecipeResponse)
  })
_sym_db.RegisterMessage(CreateRecipeResponse)

UpdateRecipeRequest = _reflection.GeneratedProtocolMessageType('UpdateRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeRequest)
  })
_sym_db.RegisterMessage(UpdateRecipeRequest)

UpdateRecipeResponse = _reflection.GeneratedProtocolMessageType('UpdateRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATERECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.UpdateRecipeResponse)
  })
_sym_db.RegisterMessage(UpdateRecipeResponse)

GetRecipeRequest = _reflection.GeneratedProtocolMessageType('GetRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeRequest)
  })
_sym_db.RegisterMessage(GetRecipeRequest)

ProfileRecipeRequest = _reflection.GeneratedProtocolMessageType('ProfileRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROFILERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeRequest)
  })
_sym_db.RegisterMessage(ProfileRecipeRequest)

ProfileRecipeResponse = _reflection.GeneratedProtocolMessageType('ProfileRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _PROFILERECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.ProfileRecipeResponse)
  })
_sym_db.RegisterMessage(ProfileRecipeResponse)

RunRecipeRequest = _reflection.GeneratedProtocolMessageType('RunRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNRECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeRequest)
  })
_sym_db.RegisterMessage(RunRecipeRequest)

RunRecipeResponse = _reflection.GeneratedProtocolMessageType('RunRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNRECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.RunRecipeResponse)
  })
_sym_db.RegisterMessage(RunRecipeResponse)

GetRecipeResponse = _reflection.GeneratedProtocolMessageType('GetRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.GetRecipeResponse)
  })
_sym_db.RegisterMessage(GetRecipeResponse)

DeleteRecipeRequest = _reflection.GeneratedProtocolMessageType('DeleteRecipeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeRequest)
  })
_sym_db.RegisterMessage(DeleteRecipeRequest)

DeleteRecipeResponse = _reflection.GeneratedProtocolMessageType('DeleteRecipeResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETERECIPERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.recipe.v1.recipe_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.recipe.v1.DeleteRecipeResponse)
  })
_sym_db.RegisterMessage(DeleteRecipeResponse)


DESCRIPTOR._options = None
_LISTRECIPESREQUEST_LABELSENTRY._options = None

_RECIPESERVICE = _descriptor.ServiceDescriptor(
  name='RecipeService',
  full_name='github.com.metaprov.modelaapi.services.recipe.v1.RecipeService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1546,
  serialized_end=2853,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListRecipes',
    full_name='github.com.metaprov.modelaapi.services.recipe.v1.RecipeService.ListRecipes',
    index=0,
    containing_service=None,
    input_type=_LISTRECIPESREQUEST,
    output_type=_LISTRECIPESRESPONSE,
    serialized_options=b'\202\323\344\223\002\r\022\013/v1/recipes',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateRecipe',
    full_name='github.com.metaprov.modelaapi.services.recipe.v1.RecipeService.CreateRecipe',
    index=1,
    containing_service=None,
    input_type=_CREATERECIPEREQUEST,
    output_type=_CREATERECIPERESPONSE,
    serialized_options=b'\202\323\344\223\002\020\"\013/v1/recipes:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetRecipe',
    full_name='github.com.metaprov.modelaapi.services.recipe.v1.RecipeService.GetRecipe',
    index=2,
    containing_service=None,
    input_type=_GETRECIPEREQUEST,
    output_type=_GETRECIPERESPONSE,
    serialized_options=b'\202\323\344\223\002\024\022\022/v1/recipes/{name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RunRecipe',
    full_name='github.com.metaprov.modelaapi.services.recipe.v1.RecipeService.RunRecipe',
    index=3,
    containing_service=None,
    input_type=_RUNRECIPEREQUEST,
    output_type=_RUNRECIPERESPONSE,
    serialized_options=b'\202\323\344\223\002\030\022\026/v1/recipes/{name}:run',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ProfileRecipe',
    full_name='github.com.metaprov.modelaapi.services.recipe.v1.RecipeService.ProfileRecipe',
    index=4,
    containing_service=None,
    input_type=_PROFILERECIPEREQUEST,
    output_type=_PROFILERECIPERESPONSE,
    serialized_options=b'\202\323\344\223\002\034\022\032/v1/recipes/{name}:profile',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateRecipe',
    full_name='github.com.metaprov.modelaapi.services.recipe.v1.RecipeService.UpdateRecipe',
    index=5,
    containing_service=None,
    input_type=_UPDATERECIPEREQUEST,
    output_type=_UPDATERECIPERESPONSE,
    serialized_options=b'\202\323\344\223\002\'\032\"/v1/recipes/{recipe.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteRecipe',
    full_name='github.com.metaprov.modelaapi.services.recipe.v1.RecipeService.DeleteRecipe',
    index=6,
    containing_service=None,
    input_type=_DELETERECIPEREQUEST,
    output_type=_DELETERECIPERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RECIPESERVICE)

DESCRIPTOR.services_by_name['RecipeService'] = _RECIPESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/report/v1/report.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/report/v1/report.proto',
  package='github.com.metaprov.modelaapi.services.report.v1',
  syntax='proto3',
  serialized_options=b'Z0github.com/metaprov/modelaapi/services/report/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=github.com/metaprov/modelaapi/services/report/v1/report.proto\x12\x30github.com.metaprov.modelaapi.services.report.v1\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\"\xc6\x01\n\x12ListReportsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12`\n\x06labels\x18\x03 \x03(\x0b\x32P.github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"j\n\x13ListReportsResponse\x12S\n\x05items\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.ReportList\"e\n\x13\x43reateReportRequest\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x16\n\x14\x43reateReportResponse\"e\n\x13UpdateReportRequest\x12N\n\x04item\x18\x05 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\"\x16\n\x14UpdateReportResponse\"3\n\x10GetReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"q\n\x11GetReportResponse\x12N\n\x04item\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Report\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"6\n\x13\x44\x65leteReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x16\n\x14\x44\x65leteReportResponse\"8\n\x15\x44ownloadReportRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"%\n\x16\x44ownloadReportResponse\x12\x0b\n\x03raw\x18\x01 \x01(\x0c\x32\xa7\t\n\rReportService\x12\xb9\x01\n\x0bListReports\x12\x44.github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest\x1a\x45.github.com.metaprov.modelaapi.services.report.v1.ListReportsResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1alpha1/reports\x12\xb5\x01\n\x0c\x43reateReport\x12\x45.github.com.metaprov.modelaapi.services.report.v1.CreateReportRequest\x1a\x46.github.com.metaprov.modelaapi.services.report.v1.CreateReportResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/reports:\x01*\x12\xc0\x01\n\tGetReport\x12\x42.github.com.metaprov.modelaapi.services.report.v1.GetReportRequest\x1a\x43.github.com.metaprov.modelaapi.services.report.v1.GetReportResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/reports/{report.metadata.name}\x12\xcc\x01\n\x0cUpdateReport\x12\x45.github.com.metaprov.modelaapi.services.report.v1.UpdateReportRequest\x1a\x46.github.com.metaprov.modelaapi.services.report.v1.UpdateReportResponse\"-\x82\xd3\xe4\x93\x02\'\x1a\"/v1/reports/{report.metadata.name}:\x01*\x12\xc9\x01\n\x0c\x44\x65leteReport\x12\x45.github.com.metaprov.modelaapi.services.report.v1.DeleteReportRequest\x1a\x46.github.com.metaprov.modelaapi.services.report.v1.DeleteReportResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/reports/{report.metadata.name}\x12\xc3\x01\n\x08\x44ownload\x12G.github.com.metaprov.modelaapi.services.report.v1.DownloadReportRequest\x1aH.github.com.metaprov.modelaapi.services.report.v1.DownloadReportResponse\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/api/v1alpha1/reports/{name}B2Z0github.com/metaprov/modelaapi/services/report/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_LISTREPORTSREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=418,
)

_LISTREPORTSREQUEST = _descriptor.Descriptor(
  name='ListReportsRequest',
  full_name='github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.labels', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTREPORTSREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=418,
)


_LISTREPORTSRESPONSE = _descriptor.Descriptor(
  name='ListReportsResponse',
  full_name='github.com.metaprov.modelaapi.services.report.v1.ListReportsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.report.v1.ListReportsResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=526,
)


_CREATEREPORTREQUEST = _descriptor.Descriptor(
  name='CreateReportRequest',
  full_name='github.com.metaprov.modelaapi.services.report.v1.CreateReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.report.v1.CreateReportRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=528,
  serialized_end=629,
)


_CREATEREPORTRESPONSE = _descriptor.Descriptor(
  name='CreateReportResponse',
  full_name='github.com.metaprov.modelaapi.services.report.v1.CreateReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=653,
)


_UPDATEREPORTREQUEST = _descriptor.Descriptor(
  name='UpdateReportRequest',
  full_name='github.com.metaprov.modelaapi.services.report.v1.UpdateReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.report.v1.UpdateReportRequest.item', index=0,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=655,
  serialized_end=756,
)


_UPDATEREPORTRESPONSE = _descriptor.Descriptor(
  name='UpdateReportResponse',
  full_name='github.com.metaprov.modelaapi.services.report.v1.UpdateReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=780,
)


_GETREPORTREQUEST = _descriptor.Descriptor(
  name='GetReportRequest',
  full_name='github.com.metaprov.modelaapi.services.report.v1.GetReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.report.v1.GetReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.report.v1.GetReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=833,
)


_GETREPORTRESPONSE = _descriptor.Descriptor(
  name='GetReportResponse',
  full_name='github.com.metaprov.modelaapi.services.report.v1.GetReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.report.v1.GetReportResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaml', full_name='github.com.metaprov.modelaapi.services.report.v1.GetReportResponse.yaml', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=835,
  serialized_end=948,
)


_DELETEREPORTREQUEST = _descriptor.Descriptor(
  name='DeleteReportRequest',
  full_name='github.com.metaprov.modelaapi.services.report.v1.DeleteReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.report.v1.DeleteReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.report.v1.DeleteReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=950,
  serialized_end=1004,
)


_DELETEREPORTRESPONSE = _descriptor.Descriptor(
  name='DeleteReportResponse',
  full_name='github.com.metaprov.modelaapi.services.report.v1.DeleteReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1006,
  serialized_end=1028,
)


_DOWNLOADREPORTREQUEST = _descriptor.Descriptor(
  name='DownloadReportRequest',
  full_name='github.com.metaprov.modelaapi.services.report.v1.DownloadReportRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='namespace', full_name='github.com.metaprov.modelaapi.services.report.v1.DownloadReportRequest.namespace', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.report.v1.DownloadReportRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1030,
  serialized_end=1086,
)


_DOWNLOADREPORTRESPONSE = _descriptor.Descriptor(
  name='DownloadReportResponse',
  full_name='github.com.metaprov.modelaapi.services.report.v1.DownloadReportResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='raw', full_name='github.com.metaprov.modelaapi.services.report.v1.DownloadReportResponse.raw', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1088,
  serialized_end=1125,
)

_LISTREPORTSREQUEST_LABELSENTRY.containing_type = _LISTREPORTSREQUEST
_LISTREPORTSREQUEST.fields_by_name['labels'].message_type = _LISTREPORTSREQUEST_LABELSENTRY
_LISTREPORTSRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORTLIST
_CREATEREPORTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_UPDATEREPORTREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
_GETREPORTRESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2._REPORT
DESCRIPTOR.message_types_by_name['ListReportsRequest'] = _LISTREPORTSREQUEST
DESCRIPTOR.message_types_by_name['ListReportsResponse'] = _LISTREPORTSRESPONSE
DESCRIPTOR.message_types_by_name['CreateReportRequest'] = _CREATEREPORTREQUEST
DESCRIPTOR.message_types_by_name['CreateReportResponse'] = _CREATEREPORTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateReportRequest'] = _UPDATEREPORTREQUEST
DESCRIPTOR.message_types_by_name['UpdateReportResponse'] = _UPDATEREPORTRESPONSE
DESCRIPTOR.message_types_by_name['GetReportRequest'] = _GETREPORTREQUEST
DESCRIPTOR.message_types_by_name['GetReportResponse'] = _GETREPORTRESPONSE
DESCRIPTOR.message_types_by_name['DeleteReportRequest'] = _DELETEREPORTREQUEST
DESCRIPTOR.message_types_by_name['DeleteReportResponse'] = _DELETEREPORTRESPONSE
DESCRIPTOR.message_types_by_name['DownloadReportRequest'] = _DOWNLOADREPORTREQUEST
DESCRIPTOR.message_types_by_name['DownloadReportResponse'] = _DOWNLOADREPORTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListReportsRequest = _reflection.GeneratedProtocolMessageType('ListReportsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTREPORTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTREPORTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.ListReportsRequest)
  })
_sym_db.RegisterMessage(ListReportsRequest)
_sym_db.RegisterMessage(ListReportsRequest.LabelsEntry)

ListReportsResponse = _reflection.GeneratedProtocolMessageType('ListReportsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTREPORTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.ListReportsResponse)
  })
_sym_db.RegisterMessage(ListReportsResponse)

CreateReportRequest = _reflection.GeneratedProtocolMessageType('CreateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.CreateReportRequest)
  })
_sym_db.RegisterMessage(CreateReportRequest)

CreateReportResponse = _reflection.GeneratedProtocolMessageType('CreateReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.CreateReportResponse)
  })
_sym_db.RegisterMessage(CreateReportResponse)

UpdateReportRequest = _reflection.GeneratedProtocolMessageType('UpdateReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.UpdateReportRequest)
  })
_sym_db.RegisterMessage(UpdateReportRequest)

UpdateReportResponse = _reflection.GeneratedProtocolMessageType('UpdateReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.UpdateReportResponse)
  })
_sym_db.RegisterMessage(UpdateReportResponse)

GetReportRequest = _reflection.GeneratedProtocolMessageType('GetReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.GetReportRequest)
  })
_sym_db.RegisterMessage(GetReportRequest)

GetReportResponse = _reflection.GeneratedProtocolMessageType('GetReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.GetReportResponse)
  })
_sym_db.RegisterMessage(GetReportResponse)

DeleteReportRequest = _reflection.GeneratedProtocolMessageType('DeleteReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DeleteReportRequest)
  })
_sym_db.RegisterMessage(DeleteReportRequest)

DeleteReportResponse = _reflection.GeneratedProtocolMessageType('DeleteReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DeleteReportResponse)
  })
_sym_db.RegisterMessage(DeleteReportResponse)

DownloadReportRequest = _reflection.GeneratedProtocolMessageType('DownloadReportRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADREPORTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DownloadReportRequest)
  })
_sym_db.RegisterMessage(DownloadReportRequest)

DownloadReportResponse = _reflection.GeneratedProtocolMessageType('DownloadReportResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADREPORTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.report.v1.report_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.report.v1.DownloadReportResponse)
  })
_sym_db.RegisterMessage(DownloadReportResponse)


DESCRIPTOR._options = None
_LISTREPORTSREQUEST_LABELSENTRY._options = None

_REPORTSERVICE = _descriptor.ServiceDescriptor(
  name='ReportService',
  full_name='github.com.metaprov.modelaapi.services.report.v1.ReportService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1128,
  serialized_end=2319,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListReports',
    full_name='github.com.metaprov.modelaapi.services.report.v1.ReportService.ListReports',
    index=0,
    containing_service=None,
    input_type=_LISTREPORTSREQUEST,
    output_type=_LISTREPORTSRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/api/v1alpha1/reports',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateReport',
    full_name='github.com.metaprov.modelaapi.services.report.v1.ReportService.CreateReport',
    index=1,
    containing_service=None,
    input_type=_CREATEREPORTREQUEST,
    output_type=_CREATEREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\"\013/v1/reports:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetReport',
    full_name='github.com.metaprov.modelaapi.services.report.v1.ReportService.GetReport',
    index=2,
    containing_service=None,
    input_type=_GETREPORTREQUEST,
    output_type=_GETREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002$\022\"/v1/reports/{report.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateReport',
    full_name='github.com.metaprov.modelaapi.services.report.v1.ReportService.UpdateReport',
    index=3,
    containing_service=None,
    input_type=_UPDATEREPORTREQUEST,
    output_type=_UPDATEREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\032\"/v1/reports/{report.metadata.name}:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteReport',
    full_name='github.com.metaprov.modelaapi.services.report.v1.ReportService.DeleteReport',
    index=4,
    containing_service=None,
    input_type=_DELETEREPORTREQUEST,
    output_type=_DELETEREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002$*\"/v1/reports/{report.metadata.name}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Download',
    full_name='github.com.metaprov.modelaapi.services.report.v1.ReportService.Download',
    index=5,
    containing_service=None,
    input_type=_DOWNLOADREPORTREQUEST,
    output_type=_DOWNLOADREPORTRESPONSE,
    serialized_options=b'\202\323\344\223\002\036*\034/api/v1alpha1/reports/{name}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_REPORTSERVICE)

DESCRIPTOR.services_by_name['ReportService'] = _REPORTSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/onlinefeaturestored/v1/onlinefeaturestored.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/onlinefeaturestored/v1/onlinefeaturestored.proto',
  package='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1',
  syntax='proto3',
  serialized_options=b'Z=github.com/metaprov/modelaapi/services/onlinefeaturestored/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nWgithub.com/metaprov/modelaapi/services/onlinefeaturestored/v1/onlinefeaturestored.proto\x12=github.com.metaprov.modelaapi.services.onlinefeaturestored.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xb9\x02\n\x14\x43reateFeatureRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02ns\x18\x02 \x01(\t\x12\x16\n\x0e\x63onnectionName\x18\x03 \x01(\t\x12O\n\x04item\x18\x04 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12o\n\x06secret\x18\x05 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x17\n\x15\x43reateFeatureResponse\"0\n\x14\x44\x65leteFeatureRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02ns\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteFeatureResponse\"!\n\x13ListFeaturesRequest\x12\n\n\x02ns\x18\x01 \x01(\t\"h\n\x14ListFeaturesResponse\x12P\n\x05items\x18\x01 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureList\"z\n\x11GetFeatureRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02ns\x18\x02 \x01(\t\x12K\n\x04item\x18\x03 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"a\n\x12GetFeatureResponse\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"+\n\rEnrichRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06record\x18\x02 \x01(\t\",\n\x0e\x45nrichResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06record\x18\x02 \x01(\t\"\xda\x02\n\x14UpdateFeatureRequest\x12K\n\x04item\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12o\n\x06secret\x18\x07 \x03(\x0b\x32_.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x17\n\x15UpdateFeatureResponse2\xf4\x08\n\x19OnlineFeatureStoreService\x12\xbc\x01\n\rCreateFeature\x12S.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest\x1aT.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureResponse\"\x00\x12\xbc\x01\n\rDeleteFeature\x12S.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureRequest\x1aT.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureResponse\"\x00\x12\xb9\x01\n\x0cListFeatures\x12R.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesRequest\x1aS.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesResponse\"\x00\x12\xb3\x01\n\nGetFeature\x12P.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureRequest\x1aQ.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureResponse\"\x00\x12\xbc\x01\n\rUpdateFeature\x12S.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest\x1aT.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureResponse\"\x00\x12\xa7\x01\n\x06\x45nrich\x12L.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichRequest\x1aM.github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichResponse\"\x00\x42?Z=github.com/metaprov/modelaapi/services/onlinefeaturestored/v1b\x06proto3'
  ,
  dependencies=[github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_CREATEFEATUREREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=609,
)

_CREATEFEATUREREQUEST = _descriptor.Descriptor(
  name='CreateFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ns', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.ns', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connectionName', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.connectionName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.item', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.secret', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEFEATUREREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=296,
  serialized_end=609,
)


_CREATEFEATURERESPONSE = _descriptor.Descriptor(
  name='CreateFeatureResponse',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=611,
  serialized_end=634,
)


_DELETEFEATUREREQUEST = _descriptor.Descriptor(
  name='DeleteFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ns', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureRequest.ns', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=636,
  serialized_end=684,
)


_DELETEFEATURERESPONSE = _descriptor.Descriptor(
  name='DeleteFeatureResponse',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=686,
  serialized_end=709,
)


_LISTFEATURESREQUEST = _descriptor.Descriptor(
  name='ListFeaturesRequest',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ns', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesRequest.ns', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=711,
  serialized_end=744,
)


_LISTFEATURESRESPONSE = _descriptor.Descriptor(
  name='ListFeaturesResponse',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='items', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesResponse.items', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=746,
  serialized_end=850,
)


_GETFEATUREREQUEST = _descriptor.Descriptor(
  name='GetFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ns', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureRequest.ns', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureRequest.item', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=852,
  serialized_end=974,
)


_GETFEATURERESPONSE = _descriptor.Descriptor(
  name='GetFeatureResponse',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureResponse.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1073,
)


_ENRICHREQUEST = _descriptor.Descriptor(
  name='EnrichRequest',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichRequest.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichRequest.record', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1075,
  serialized_end=1118,
)


_ENRICHRESPONSE = _descriptor.Descriptor(
  name='EnrichResponse',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichResponse.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='record', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichResponse.record', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1164,
)


_UPDATEFEATUREREQUEST_SECRETENTRY = _descriptor.Descriptor(
  name='SecretEntry',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.SecretEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.SecretEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.SecretEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=564,
  serialized_end=609,
)

_UPDATEFEATUREREQUEST = _descriptor.Descriptor(
  name='UpdateFeatureRequest',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='item', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.item', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.secret', index=2,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEFEATUREREQUEST_SECRETENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1167,
  serialized_end=1513,
)


_UPDATEFEATURERESPONSE = _descriptor.Descriptor(
  name='UpdateFeatureResponse',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1515,
  serialized_end=1538,
)

_CREATEFEATUREREQUEST_SECRETENTRY.containing_type = _CREATEFEATUREREQUEST
_CREATEFEATUREREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_CREATEFEATUREREQUEST.fields_by_name['secret'].message_type = _CREATEFEATUREREQUEST_SECRETENTRY
_LISTFEATURESRESPONSE.fields_by_name['items'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURELIST
_GETFEATUREREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE
_GETFEATURERESPONSE.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE
_UPDATEFEATUREREQUEST_SECRETENTRY.containing_type = _UPDATEFEATUREREQUEST
_UPDATEFEATUREREQUEST.fields_by_name['item'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2._FEATURE
_UPDATEFEATUREREQUEST.fields_by_name['connection'].message_type = github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2._CONNECTION
_UPDATEFEATUREREQUEST.fields_by_name['secret'].message_type = _UPDATEFEATUREREQUEST_SECRETENTRY
DESCRIPTOR.message_types_by_name['CreateFeatureRequest'] = _CREATEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['CreateFeatureResponse'] = _CREATEFEATURERESPONSE
DESCRIPTOR.message_types_by_name['DeleteFeatureRequest'] = _DELETEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['DeleteFeatureResponse'] = _DELETEFEATURERESPONSE
DESCRIPTOR.message_types_by_name['ListFeaturesRequest'] = _LISTFEATURESREQUEST
DESCRIPTOR.message_types_by_name['ListFeaturesResponse'] = _LISTFEATURESRESPONSE
DESCRIPTOR.message_types_by_name['GetFeatureRequest'] = _GETFEATUREREQUEST
DESCRIPTOR.message_types_by_name['GetFeatureResponse'] = _GETFEATURERESPONSE
DESCRIPTOR.message_types_by_name['EnrichRequest'] = _ENRICHREQUEST
DESCRIPTOR.message_types_by_name['EnrichResponse'] = _ENRICHRESPONSE
DESCRIPTOR.message_types_by_name['UpdateFeatureRequest'] = _UPDATEFEATUREREQUEST
DESCRIPTOR.message_types_by_name['UpdateFeatureResponse'] = _UPDATEFEATURERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateFeatureRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEFEATUREREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureRequest)
  })
_sym_db.RegisterMessage(CreateFeatureRequest)
_sym_db.RegisterMessage(CreateFeatureRequest.SecretEntry)

CreateFeatureResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.CreateFeatureResponse)
  })
_sym_db.RegisterMessage(CreateFeatureResponse)

DeleteFeatureRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureRequest)

DeleteFeatureResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.DeleteFeatureResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureResponse)

ListFeaturesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesRequest)
  })
_sym_db.RegisterMessage(ListFeaturesRequest)

ListFeaturesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.ListFeaturesResponse)
  })
_sym_db.RegisterMessage(ListFeaturesResponse)

GetFeatureRequest = _reflection.GeneratedProtocolMessageType('GetFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureRequest)
  })
_sym_db.RegisterMessage(GetFeatureRequest)

GetFeatureResponse = _reflection.GeneratedProtocolMessageType('GetFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.GetFeatureResponse)
  })
_sym_db.RegisterMessage(GetFeatureResponse)

EnrichRequest = _reflection.GeneratedProtocolMessageType('EnrichRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENRICHREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichRequest)
  })
_sym_db.RegisterMessage(EnrichRequest)

EnrichResponse = _reflection.GeneratedProtocolMessageType('EnrichResponse', (_message.Message,), {
  'DESCRIPTOR' : _ENRICHRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.EnrichResponse)
  })
_sym_db.RegisterMessage(EnrichResponse)

UpdateFeatureRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEFEATUREREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureRequest)
_sym_db.RegisterMessage(UpdateFeatureRequest.SecretEntry)

UpdateFeatureResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.onlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.UpdateFeatureResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureResponse)


DESCRIPTOR._options = None
_CREATEFEATUREREQUEST_SECRETENTRY._options = None
_UPDATEFEATUREREQUEST_SECRETENTRY._options = None

_ONLINEFEATURESTORESERVICE = _descriptor.ServiceDescriptor(
  name='OnlineFeatureStoreService',
  full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1541,
  serialized_end=2681,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateFeature',
    full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService.CreateFeature',
    index=0,
    containing_service=None,
    input_type=_CREATEFEATUREREQUEST,
    output_type=_CREATEFEATURERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteFeature',
    full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService.DeleteFeature',
    index=1,
    containing_service=None,
    input_type=_DELETEFEATUREREQUEST,
    output_type=_DELETEFEATURERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListFeatures',
    full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService.ListFeatures',
    index=2,
    containing_service=None,
    input_type=_LISTFEATURESREQUEST,
    output_type=_LISTFEATURESRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetFeature',
    full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService.GetFeature',
    index=3,
    containing_service=None,
    input_type=_GETFEATUREREQUEST,
    output_type=_GETFEATURERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateFeature',
    full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService.UpdateFeature',
    index=4,
    containing_service=None,
    input_type=_UPDATEFEATUREREQUEST,
    output_type=_UPDATEFEATURERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Enrich',
    full_name='github.com.metaprov.modelaapi.services.onlinefeaturestored.v1.OnlineFeatureStoreService.Enrich',
    index=5,
    containing_service=None,
    input_type=_ENRICHREQUEST,
    output_type=_ENRICHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ONLINEFEATURESTORESERVICE)

DESCRIPTOR.services_by_name['OnlineFeatureStoreService'] = _ONLINEFEATURESTORESERVICE

# @@protoc_insertion_point(module_scope)
